RiboMetric results

####

Read Frame Distribution Metagene Profile Metagene Heatmap mRNA Reads Breakdown mRNA Reads Breakdown over Read Length Ligation Bias Distribution Nucleotide Composition Read Length Distribution

# RiboMetric Report

##### Results from your RiboMetric analysis, completed at 10:09:05 02/06/2023

## Summary Report

Read length distribution metric | 0.521
Ligation bias distribution metric | 0.142
3nt weighted score | 0.152
3nt weighted score best 3 read lengths | 0.058
Cds coverage metric | 0.0

## Read Frame Distribution

Frame distribution per read length

## Metagene Profile

Metagene profile showing the distance count of reads per distance away from a target (default: start codon).

## Metagene Heatmap

Metagene heatmap showing the distance between the A-site and a target per read length and the counts in colorscale.

## mRNA Reads Breakdown

Shows the proportion of the different transcript regions represented in the reads

## mRNA Reads Breakdown over Read Length

Shows the proportion of the different transcript regions represented in the reads over the different read lengths.

## Ligation Bias Distribution

Distribution of end bases for the full dataset

## Nucleotide Composition

Nucleotide composition of the reads

## Read Length Distribution

Distribution of read lengths for the full dataset